@@ -18,11 +18,14 @@ libcloud provides a unified interface to the cloud computing resources.
 
 :var __version__: Current version of libcloud
 """
-
-
 import os
 import codecs
 
+from libcloud.base import DriverType  # NOQA
+from libcloud.base import DriverTypeFactoryMap  # NOQA
+from libcloud.base import get_driver  # NOQA
+
+
 try:
     import paramiko
     have_paramiko = True
@@ -33,7 +36,7 @@ __all__ = [
     '__version__',
     'enable_debug'
 ]
-__version__ = '1.2.1'
+__version__ = '1.3.0'
 
 
 def enable_debug(fo):
